Place
=====

.. currentmodule:: wwt_data_formats.place

.. autoclass:: Place
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Place.angle
      ~Place.angular_size
      ~Place.background_image_set
      ~Place.classification
      ~Place.constellation
      ~Place.data_set_type
      ~Place.dec_deg
      ~Place.description
      ~Place.distance
      ~Place.dome_alt
      ~Place.dome_az
      ~Place.foreground_image_set
      ~Place.image_set
      ~Place.latitude
      ~Place.longitude
      ~Place.magnitude
      ~Place.msr_community_id
      ~Place.msr_component_id
      ~Place.name
      ~Place.opacity
      ~Place.permission
      ~Place.ra_hr
      ~Place.rotation_deg
      ~Place.thumbnail
      ~Place.zoom_level

   .. rubric:: Methods Summary

   .. autosummary::

      ~Place.to_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: angle
   .. autoattribute:: angular_size
   .. autoattribute:: background_image_set
   .. autoattribute:: classification
   .. autoattribute:: constellation
   .. autoattribute:: data_set_type
   .. autoattribute:: dec_deg
   .. autoattribute:: description
   .. autoattribute:: distance
   .. autoattribute:: dome_alt
   .. autoattribute:: dome_az
   .. autoattribute:: foreground_image_set
   .. autoattribute:: image_set
   .. autoattribute:: latitude
   .. autoattribute:: longitude
   .. autoattribute:: magnitude
   .. autoattribute:: msr_community_id
   .. autoattribute:: msr_component_id
   .. autoattribute:: name
   .. autoattribute:: opacity
   .. autoattribute:: permission
   .. autoattribute:: ra_hr
   .. autoattribute:: rotation_deg
   .. autoattribute:: thumbnail
   .. autoattribute:: zoom_level

   .. rubric:: Methods Documentation

   .. automethod:: to_xml
